%     Copyright (C) 2023 Jordi Cano. Contact: jordi.cg89@gmail.com
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function Analize_good_sims()
% Analize_good_sims Applies more restrictions and builds various plots
close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
population_name     = 'Population_50000_each.mat';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0 for initial endocardial good population
% 1 for population after selecting viable endocardial cells and partners
% 2 for population of mid and epi cells after selecting viable ones
analize_toSim_pop   = 0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load the pertinent file
goodfolder          = [population_name(1:end-4) '_plots'];
if analize_toSim_pop == 0
    goodfile            = [population_name(1:end-4) '_good.mat']; % include .mat
elseif analize_toSim_pop == 1
    goodfile            = [population_name(1:end-4) '_partners_toSim.mat']; % include .mat
elseif analize_toSim_pop == 2
    goodfolder          = [population_name(1:end-4) '_toSim_plots'];
    goodfile            = [population_name(1:end-4) '_good.mat']; % include .mat
end
if analize_toSim_pop == 1
    L                   = load([goodfile]);
else
    L                   = load([goodfolder '\' goodfile]);
end

S                   = L;
if analize_toSim_pop == 0 || analize_toSim_pop == 2
    S                   = L.S;
end

% make boxplots
plot_these          = [S.APD90s S.APD50s S.APD40s S.Tri90_40s S.RMPs S.maxVs S.maxdVdTs S.maxCais];
LEG                 = {'APD90', 'APD50', 'APD40', 'Tri90-40', 'RMP', 'maxV', 'maxdVdT', 'maxCai'};
FIGS                = size(plot_these,2);

if analize_toSim_pop == 2
    EPI                 = S.cells == 1;
    MID                 = S.cells == 2;
    plot_these_epi      = plot_these(EPI,:);
    plot_these_mid      = plot_these(MID,:);
end

for i = 1:FIGS
    if analize_toSim_pop == 0
        figure(); hold on;
        boxplot(plot_these(:,i), S.genders);
        title([LEG{i} ' (Males = 1, Females = 2)'])
        saveas(gcf,[goodfolder '\' LEG{i} '_boxplot.fig']);
        
    elseif analize_toSim_pop == 1
        figure(); hold on;
        boxplot(plot_these(:,i), S.genders);
        title([LEG{i} ' (Males = 1, Females = 2)'])
        saveas(gcf,[goodfolder '\' LEG{i} 'toSim_boxplot_ENDO.fig']);
        
    elseif analize_toSim_pop == 2
        figure(); hold on;
        boxplot(plot_these_epi(:,i), S.genders(EPI));
        title([LEG{i} ' (Males = 1, Females = 2)'])
        saveas(gcf,[goodfolder '\' LEG{i} '_boxplot_EPI.fig']);
        
        figure(); hold on;
        boxplot(plot_these_mid(:,i), S.genders(MID));
        title([LEG{i} ' (Males = 1, Females = 2)'])
        saveas(gcf,[goodfolder '\' LEG{i} '_boxplot_MID.fig']);
        
    else
        
    end
end
end
