%     Copyright (C) 2023 Jordi Cano. Contact: jordi.cg89@gmail.com
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function Simulate_toSim_population()
%Simulate_population Simulates the AP models with the parameters of the
%population, completing a previously curated endocardial pop
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

main_pop_path = 'Population_50000_each.mat';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% parameters of the simulations
executable  = 'ORdmD_sex';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% this code detects the number of processors then opens a parallel pool
if isunix; [~, MAXJOBS] = system('nproc'); elseif ispc; MAXJOBS = getenv('NUMBER_OF_PROCESSORS'); end
MAXJOBS          = str2double(MAXJOBS); % change to number
parOptions       = parcluster ('local');
parOptions.NumWorkers = MAXJOBS;
pool             = parpool('local', MAXJOBS);
pool.IdleTimeout = Inf;   % Set 'No automatic shut down'

% check things
if isunix; bar = '/'; else; bar = '\'; end

Popmatrixpath = [main_pop_path(1:end-4) '_good.mat'];

% load the matrix
L               = load(Popmatrixpath);
N               = size(L.IDs,1);
channels        = L.channels;

MID = 2;
EPI = 1;

% assign variables to each ID in a big matrix to convert later
parameters1     = [ L.IDs  zeros(N,1)+MID  L.genders  L.phases  L.BCLs  L.BEATs  L.SVSTs  L.SVPs  L.scalars];
parameters2     = [ L.IDs  zeros(N,1)+EPI  L.genders  L.phases  L.BCLs  L.BEATs  L.SVSTs  L.SVPs  L.scalars];
parameters      = [parameters1; parameters2];

% convert parameter lists to commands
Ncoms           = size(parameters,1);

commands        = cell(Ncoms,1);
for i = 1:Ncoms
    commands{i} = ['nohup > ToSim_ID_' num2str(parameters(i,1)) '.log ' '.' bar executable ' ' Double2text(parameters(i,:))];
end

savename = [Popmatrixpath(1:end-4) '_commands.mat'];
save(savename,'commands','parameters','channels');

allIDs  = parameters(:,1);
cellty  = parameters(:,2);
genders = parameters(:,3);
phases  = parameters(:,4);

% check if the files exist
alreadydone = 0;
donemat     = ones(Ncoms,1);
for i = 1:Ncoms
    if genders(i) == 1; g = 'm'; else; g = 'f'; end
    if cellty(i) == 2; ct = 'MID'; else; ct = 'EPI'; end
    pha = phases(i);
    
    thisfile    = ['res_' num2str(allIDs(i)) '_' ct g '_p' num2str(pha) '.txt'];
    fileisthere =  exist(thisfile, 'file');
    
    if fileisthere==2
        
        f           = dir(thisfile);
        mem         = f(1).bytes;
        sizeisok    = mem > 7e5;
        
        if sizeisok
            donemat(i)  = 0;
            alreadydone = alreadydone+1;
        end
        
    end
end
disp(['Skipping ' num2str(alreadydone) ' simulations because files were already present.']);

% select only the ones that haven't yet been done
donebool        = donemat == 1; % 1 = to do
commands_to_do  = commands(donebool,1);

parfor kk = 1:length(commands_to_do)
    com = commands_to_do{kk};
    system(com);
end

end

